@@ -4,6 +4,7 @@ from tensorflow import keras
 from tensorflow.keras import Sequential
 
 from model_data_util.constant import OPTIONS, ONE_HOT_ENC, NUM_DIM
+from model_data_util.create_tt_data.generate_tt_data import createInputbyModel
 
 
 def convertModelToRawData(model, columns, num_data, num_dim=NUM_DIM):
@@ -28,6 +29,8 @@ def convertModelToRawData(model, columns, num_data, num_dim=NUM_DIM):
             out_shape = np.array(model.layers[i - 1].output.shape)
         elif i == 0 and l_name == "InputLayer":
             out_shape = np.array(conf['batch_input_shape'])
+        elif i == 0 and l_name != "inputlayer":
+            out_shape = createInputbyModel(model)[0].shape
         if out_shape is not None:
             assert out_shape.shape[0] <= num_dim
             for j in range(num_dim):
